@@ -32,7 +32,7 @@ __all__ = [
 	'JSet',
 	# .addressing
 	'IPv4', 'IPv6', 'addressing', 'Validation', 'get_summaries', 'isSubset',
-	'binsubnet', 'bin2dec', 'bin2decmask', 'to_dec_mask', 'bin_mask', 'Routes',
+	'binsubnet', 'bin2dec', 'bin2decmask', 'to_dec_mask', 'bin_mask', 'Routes', 'invmask_to_mask',
 	# .gpl
 	'Default', 'Container', 'Numeric', 'DifferenceDict', 
 	'STR', 'IO', 'LST', 'DIC', 'LOG', 'DB', 'IP', 'XL_READ', 'XL_WRITE', 
@@ -54,14 +54,14 @@ __all__ = [
 
 	]
 
-__version__ = "0.0.19"
+__version__ = "0.0.20"
 
 from .juniper import Juniper
 from .jset import JSet
 
 from .addressing import (
 	IPv4, IPv6, addressing, Validation, get_summaries, isSubset,
-	binsubnet, bin2dec, bin2decmask, to_dec_mask, bin_mask, Routes,
+	binsubnet, bin2dec, bin2decmask, to_dec_mask, bin_mask, Routes, invmask_to_mask,
 	)
 
 from .gpl import (Default, Container, Numeric, 
